@@ -3,7 +3,7 @@ package BioX::Workflow::Plugin::FileExists;
 use strict;
 
 use 5.008_005;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Data::Dumper;
 use Data::Pairs;
@@ -13,15 +13,18 @@ use Moose::Role;
 before 'write_process' => sub{
     my $self = shift;
 
-    print "# In before write process!\n";
+    $DB::single=2;
     my $process = $self->process;
-    chomp($process);
 
     my @input =  $self->local_attr->get_values('INPUT') if $self->local_attr->exists('INPUT');
     my @output =  $self->local_attr->get_values('OUTPUT') if $self->local_attr->exists('OUTPUT');
 
     my($input, $output) = ($input[0], $output[0]);
 
+    if(!$input && !$output){
+        return;
+    }
+
     my $tprocess = "";
     if($input){
         $tprocess .=<<EOF;
@@ -38,6 +41,7 @@ EOF
         $process = $tprocess;
     }
     if($output){
+        chomp($process);
         $process = $process." && \\\n";
         $tprocess =<<EOF;
 [ -f "$output"  ] || \\{>&2 echo "OUTPUT $output not found" ;  \\} && \\
@@ -45,6 +49,7 @@ EOF
 EOF
         $process .= $tprocess;
     }
+    $DB::single=2;
     $self->process($process);
 
 };
